@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ from .cluster_service import (
     AutoprovisioningNodePoolDefaults,
     AutoUpgradeOptions,
     BinaryAuthorization,
+    BlueGreenSettings,
     CancelOperationRequest,
     ClientCertificateConfig,
     CloudRunConfig,
@@ -29,12 +30,14 @@ from .cluster_service import (
     ClusterAutoscaling,
     ClusterUpdate,
     CompleteIPRotationRequest,
+    CompleteNodePoolUpgradeRequest,
     ConfidentialNodes,
     ConfigConnectorConfig,
     CreateClusterRequest,
     CreateNodePoolRequest,
     DailyMaintenanceWindow,
     DatabaseEncryption,
+    DatapathProvider,
     DefaultSnatStatus,
     DeleteClusterRequest,
     DeleteNodePoolRequest,
@@ -51,8 +54,10 @@ from .cluster_service import (
     GetOpenIDConfigResponse,
     GetOperationRequest,
     GetServerConfigRequest,
+    GPUSharingConfig,
     HorizontalPodAutoscaling,
     HttpLoadBalancing,
+    IdentityServiceConfig,
     ILBSubsettingConfig,
     IntraNodeVisibilityConfig,
     IPAllocationPolicy,
@@ -73,6 +78,7 @@ from .cluster_service import (
     MaintenanceExclusionOptions,
     MaintenancePolicy,
     MaintenanceWindow,
+    ManagedPrometheusConfig,
     MasterAuth,
     MasterAuthorizedNetworksConfig,
     MaxPodsConstraint,
@@ -82,20 +88,26 @@ from .cluster_service import (
     NetworkConfig,
     NetworkPolicy,
     NetworkPolicyConfig,
+    NetworkTags,
     NodeConfig,
     NodeConfigDefaults,
     NodeKubeletConfig,
+    NodeLabels,
     NodeManagement,
     NodeNetworkConfig,
     NodePool,
+    NodePoolAutoConfig,
     NodePoolAutoscaling,
     NodePoolDefaults,
+    NodePoolUpdateStrategy,
     NodeTaint,
+    NodeTaints,
     NotificationConfig,
     Operation,
     OperationProgress,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
+    PrivateIPv6GoogleAccess,
     RecurringTimeWindow,
     ReleaseChannel,
     ReservationAffinity,
@@ -128,15 +140,13 @@ from .cluster_service import (
     UpdateNodePoolRequest,
     UpgradeAvailableEvent,
     UpgradeEvent,
+    UpgradeResourceType,
     UsableSubnetwork,
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
-    DatapathProvider,
-    PrivateIPv6GoogleAccess,
-    UpgradeResourceType,
 )
 
 __all__ = (
@@ -148,6 +158,7 @@ __all__ = (
     "AutoprovisioningNodePoolDefaults",
     "AutoUpgradeOptions",
     "BinaryAuthorization",
+    "BlueGreenSettings",
     "CancelOperationRequest",
     "ClientCertificateConfig",
     "CloudRunConfig",
@@ -155,6 +166,7 @@ __all__ = (
     "ClusterAutoscaling",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "CompleteNodePoolUpgradeRequest",
     "ConfidentialNodes",
     "ConfigConnectorConfig",
     "CreateClusterRequest",
@@ -177,8 +189,10 @@ __all__ = (
     "GetOpenIDConfigResponse",
     "GetOperationRequest",
     "GetServerConfigRequest",
+    "GPUSharingConfig",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
+    "IdentityServiceConfig",
     "ILBSubsettingConfig",
     "IntraNodeVisibilityConfig",
     "IPAllocationPolicy",
@@ -199,6 +213,7 @@ __all__ = (
     "MaintenanceExclusionOptions",
     "MaintenancePolicy",
     "MaintenanceWindow",
+    "ManagedPrometheusConfig",
     "MasterAuth",
     "MasterAuthorizedNetworksConfig",
     "MaxPodsConstraint",
@@ -208,15 +223,19 @@ __all__ = (
     "NetworkConfig",
     "NetworkPolicy",
     "NetworkPolicyConfig",
+    "NetworkTags",
     "NodeConfig",
     "NodeConfigDefaults",
     "NodeKubeletConfig",
+    "NodeLabels",
     "NodeManagement",
     "NodeNetworkConfig",
     "NodePool",
+    "NodePoolAutoConfig",
     "NodePoolAutoscaling",
     "NodePoolDefaults",
     "NodeTaint",
+    "NodeTaints",
     "NotificationConfig",
     "Operation",
     "OperationProgress",
@@ -261,6 +280,7 @@ __all__ = (
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
+    "NodePoolUpdateStrategy",
     "PrivateIPv6GoogleAccess",
     "UpgradeResourceType",
 )
