@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ from .cluster_service import (
     AutoprovisioningNodePoolDefaults,
     AutoUpgradeOptions,
     BinaryAuthorization,
+    BlueGreenSettings,
     CancelOperationRequest,
     ClientCertificateConfig,
     CloudRunConfig,
@@ -30,12 +31,15 @@ from .cluster_service import (
     ClusterTelemetry,
     ClusterUpdate,
     CompleteIPRotationRequest,
+    CompleteNodePoolUpgradeRequest,
     ConfidentialNodes,
     ConfigConnectorConfig,
+    CostManagementConfig,
     CreateClusterRequest,
     CreateNodePoolRequest,
     DailyMaintenanceWindow,
     DatabaseEncryption,
+    DatapathProvider,
     DefaultSnatStatus,
     DeleteClusterRequest,
     DeleteNodePoolRequest,
@@ -54,6 +58,7 @@ from .cluster_service import (
     GetOperationRequest,
     GetServerConfigRequest,
     GkeBackupAgentConfig,
+    GPUSharingConfig,
     HorizontalPodAutoscaling,
     HttpLoadBalancing,
     IdentityServiceConfig,
@@ -101,8 +106,10 @@ from .cluster_service import (
     NodeManagement,
     NodeNetworkConfig,
     NodePool,
+    NodePoolAutoConfig,
     NodePoolAutoscaling,
     NodePoolDefaults,
+    NodePoolUpdateStrategy,
     NodeTaint,
     NodeTaints,
     NotificationConfig,
@@ -111,6 +118,8 @@ from .cluster_service import (
     PodSecurityPolicyConfig,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
+    PrivateIPv6GoogleAccess,
+    ProtectConfig,
     RecurringTimeWindow,
     ReleaseChannel,
     ReservationAffinity,
@@ -144,17 +153,17 @@ from .cluster_service import (
     UpdateNodePoolRequest,
     UpgradeAvailableEvent,
     UpgradeEvent,
+    UpgradeResourceType,
     UsableSubnetwork,
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
     WindowsVersions,
+    WorkloadALTSConfig,
     WorkloadCertificates,
+    WorkloadConfig,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
-    DatapathProvider,
-    PrivateIPv6GoogleAccess,
-    UpgradeResourceType,
 )
 
 __all__ = (
@@ -166,6 +175,7 @@ __all__ = (
     "AutoprovisioningNodePoolDefaults",
     "AutoUpgradeOptions",
     "BinaryAuthorization",
+    "BlueGreenSettings",
     "CancelOperationRequest",
     "ClientCertificateConfig",
     "CloudRunConfig",
@@ -174,8 +184,10 @@ __all__ = (
     "ClusterTelemetry",
     "ClusterUpdate",
     "CompleteIPRotationRequest",
+    "CompleteNodePoolUpgradeRequest",
     "ConfidentialNodes",
     "ConfigConnectorConfig",
+    "CostManagementConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
     "DailyMaintenanceWindow",
@@ -198,6 +210,7 @@ __all__ = (
     "GetOperationRequest",
     "GetServerConfigRequest",
     "GkeBackupAgentConfig",
+    "GPUSharingConfig",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
     "IdentityServiceConfig",
@@ -245,6 +258,7 @@ __all__ = (
     "NodeManagement",
     "NodeNetworkConfig",
     "NodePool",
+    "NodePoolAutoConfig",
     "NodePoolAutoscaling",
     "NodePoolDefaults",
     "NodeTaint",
@@ -255,6 +269,7 @@ __all__ = (
     "PodSecurityPolicyConfig",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
+    "ProtectConfig",
     "RecurringTimeWindow",
     "ReleaseChannel",
     "ReservationAffinity",
@@ -293,10 +308,13 @@ __all__ = (
     "VerticalPodAutoscaling",
     "VirtualNIC",
     "WindowsVersions",
+    "WorkloadALTSConfig",
     "WorkloadCertificates",
+    "WorkloadConfig",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
+    "NodePoolUpdateStrategy",
     "PrivateIPv6GoogleAccess",
     "UpgradeResourceType",
 )
