@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,6 +41,7 @@ class containerCallTransformer(cst.CSTTransformer):
     METHOD_TO_PARAMS: Dict[str, Tuple[str]] = {
         'cancel_operation': ('project_id', 'zone', 'operation_id', 'name', ),
         'complete_ip_rotation': ('project_id', 'zone', 'cluster_id', 'name', ),
+        'complete_node_pool_upgrade': ('name', ),
         'create_cluster': ('project_id', 'zone', 'cluster', 'parent', ),
         'create_node_pool': ('project_id', 'zone', 'cluster_id', 'node_pool', 'parent', ),
         'delete_cluster': ('project_id', 'zone', 'cluster_id', 'name', ),
@@ -55,7 +56,7 @@ class containerCallTransformer(cst.CSTTransformer):
         'list_node_pools': ('project_id', 'zone', 'cluster_id', 'parent', ),
         'list_operations': ('project_id', 'zone', 'parent', ),
         'list_usable_subnetworks': ('parent', 'filter', 'page_size', 'page_token', ),
-        'rollback_node_pool_upgrade': ('project_id', 'zone', 'cluster_id', 'node_pool_id', 'name', ),
+        'rollback_node_pool_upgrade': ('project_id', 'zone', 'cluster_id', 'node_pool_id', 'name', 'respect_pdb', ),
         'set_addons_config': ('project_id', 'zone', 'cluster_id', 'addons_config', 'name', ),
         'set_labels': ('project_id', 'zone', 'cluster_id', 'resource_labels', 'label_fingerprint', 'name', ),
         'set_legacy_abac': ('project_id', 'zone', 'cluster_id', 'enabled', 'name', ),
@@ -71,7 +72,7 @@ class containerCallTransformer(cst.CSTTransformer):
         'start_ip_rotation': ('project_id', 'zone', 'cluster_id', 'name', 'rotate_credentials', ),
         'update_cluster': ('project_id', 'zone', 'cluster_id', 'update', 'name', ),
         'update_master': ('project_id', 'zone', 'cluster_id', 'master_version', 'name', ),
-        'update_node_pool': ('project_id', 'zone', 'cluster_id', 'node_pool_id', 'node_version', 'image_type', 'locations', 'workload_metadata_config', 'name', 'upgrade_settings', 'tags', 'taints', 'labels', 'linux_node_config', 'kubelet_config', 'gcfs_config', 'gvnic', ),
+        'update_node_pool': ('project_id', 'zone', 'cluster_id', 'node_pool_id', 'node_version', 'image_type', 'locations', 'workload_metadata_config', 'name', 'upgrade_settings', 'tags', 'taints', 'labels', 'linux_node_config', 'kubelet_config', 'node_network_config', 'gcfs_config', 'confidential_nodes', 'gvnic', ),
     }
 
     def leave_Call(self, original: cst.Call, updated: cst.Call) -> cst.CSTNode:
